==> jc-1.4.0.tar.gz: soot/javaToJimple/ClassLiteralMethodSource.h <==
// public class soot.javaToJimple.ClassLiteralMethodSource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 822c068f1364896e soot_javaToJimple_ClassLiteralMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_ClassLiteralMethodSource_H_
#define _JC_soot_javaToJimple_ClassLiteralMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_refs	_jc_soot_javaToJimple_ClassLiteralMethodSource$sub_refs;
typedef struct _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_nonrefs	_jc_soot_javaToJimple_ClassLiteralMethodSource$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_ClassLiteralMethodSource$refs	_jc_soot_javaToJimple_ClassLiteralMethodSource$refs;
typedef struct _jc_soot_javaToJimple_ClassLiteralMethodSource$nonrefs	_jc_soot_javaToJimple_ClassLiteralMethodSource$nonrefs;
typedef struct _jc_soot_javaToJimple_ClassLiteralMethodSource$object	_jc_soot_javaToJimple_ClassLiteralMethodSource$object;

typedef const struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vmethods	_jc_soot_javaToJimple_ClassLiteralMethodSource$vmethods;
typedef const struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vtable	_jc_soot_javaToJimple_ClassLiteralMethodSource$vtable;
typedef const struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vtype	_jc_soot_javaToJimple_ClassLiteralMethodSource$vtype;

// Constructors
extern void _jc_soot_javaToJimple_ClassLiteralMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralMethodSource$object *);

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_javaToJimple_ClassLiteralMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_ClassLiteralMethodSource$method_info$getBody$01a871f1d690f082;

// Virtual methods structure
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_ClassLiteralMethodSource$vmethods	soot_javaToJimple_ClassLiteralMethodSource;
};

// Vtype
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_ClassLiteralMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$refs {
    _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_refs	soot_javaToJimple_ClassLiteralMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_nonrefs	soot_javaToJimple_ClassLiteralMethodSource;
};

// Object instance structure
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$object {
	_jc_soot_javaToJimple_ClassLiteralMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_ClassLiteralMethodSource$vtype	*vtype;
	_jc_soot_javaToJimple_ClassLiteralMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_ClassLiteralMethodSource$vtype _jc_soot_javaToJimple_ClassLiteralMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_ClassLiteralMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_ClassLiteralMethodSource$class_object;

#endif	/* _JC_soot_javaToJimple_ClassLiteralMethodSource_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/ClassLiteralMethodSource.h <==
// public class soot.javaToJimple.ClassLiteralMethodSource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 822c068f1364896e soot_javaToJimple_ClassLiteralMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_ClassLiteralMethodSource_H_
#define _JC_soot_javaToJimple_ClassLiteralMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_refs	_jc_soot_javaToJimple_ClassLiteralMethodSource$sub_refs;
typedef struct _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_nonrefs	_jc_soot_javaToJimple_ClassLiteralMethodSource$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_ClassLiteralMethodSource$refs	_jc_soot_javaToJimple_ClassLiteralMethodSource$refs;
typedef struct _jc_soot_javaToJimple_ClassLiteralMethodSource$nonrefs	_jc_soot_javaToJimple_ClassLiteralMethodSource$nonrefs;
typedef struct _jc_soot_javaToJimple_ClassLiteralMethodSource$object	_jc_soot_javaToJimple_ClassLiteralMethodSource$object;

typedef const struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vmethods	_jc_soot_javaToJimple_ClassLiteralMethodSource$vmethods;
typedef const struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vtable	_jc_soot_javaToJimple_ClassLiteralMethodSource$vtable;
typedef const struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vtype	_jc_soot_javaToJimple_ClassLiteralMethodSource$vtype;

// Constructors
extern void _jc_soot_javaToJimple_ClassLiteralMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralMethodSource$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_javaToJimple_ClassLiteralMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_ClassLiteralMethodSource$method_info$getBody$01a871f1d690f082;

// Virtual methods structure
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_ClassLiteralMethodSource$vmethods	soot_javaToJimple_ClassLiteralMethodSource;
};

// Vtype
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_ClassLiteralMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$refs {
    _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_refs	soot_javaToJimple_ClassLiteralMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_ClassLiteralMethodSource$sub_nonrefs	soot_javaToJimple_ClassLiteralMethodSource;
};

// Object instance structure
struct _jc_soot_javaToJimple_ClassLiteralMethodSource$object {
	_jc_soot_javaToJimple_ClassLiteralMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_ClassLiteralMethodSource$vtype	*vtype;
	_jc_soot_javaToJimple_ClassLiteralMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_ClassLiteralMethodSource$vtype _jc_soot_javaToJimple_ClassLiteralMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_ClassLiteralMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_ClassLiteralMethodSource$class_object;

#endif	/* _JC_soot_javaToJimple_ClassLiteralMethodSource_H_ */
